;----------------------------------------------------------------------
;
;  Portable Document file (PDF) Plotter Driver Configuration file
;
;  Revision:	1.2
;  File:	pdf_FullMono.plt
;  Created:	2005/02/07
;  Revised:	2017/08/31	- Revised paper size options and names
;
;----------------------------------------------------------------------

;======================================================================
;
;   >>>>> WARNING  WARNING  WARNING  WARNING  WARNING  WARNING  <<<<<
;  
;  Plotter driver configuration files are now stored in two directories:
;
;    $(_USTN_WORKSPACEROOT)/System/plotdrv/
;    $(_USTN_WORKSPACEROOT)/Standards/plotdrv/
;
;  System/plotdrv/ should be reserved for .plt files delivered by
;  MicroStation and other Bentley products. Standards/plotdrv/ is
;  provided as a place for you to store customized .plt files. To
;  simplify plotter selection from the Plot dialog, you may also
;  elect to store frequently-used .plt files in Standards/plotdrv/
;  even if you do not customize them.
;
;  To minimize the risk of losing your changes during a product
;  reinstallation, do not edit the files in the System/plotdrv/
;  directory. Instead, copy the necessary files to Standards/plotdrv/
;  and edit them there. If the .plt file depends on other files, such
;  as PostScript prolog (*.pro) files, copy them to the same directory.
;
;======================================================================
; Construction/active points are plotted by default. Comment out the next line
; if you do not want points plotted.

;point_size          = 0.03
default_extension   = 'pdf'       ; default extension for plotfiles
document_set
model               = mdl
driver              = pdf
autocenter                      ; Automatically center plot on page

num_pens = 255 ; required record, must precede any "pen" records.
change_pen = both

; Remove this record if no border is desired.
; Refer to the documentation for available border qualifiers.
;border /filename /time /text_height=0.35

; Substitute the name of a pentable file to be loaded when this driver is selected
;pentable=\dir\file.tbl

;=================================================================
;Turn the Book Marks on and off
CmdName /appname="pdf" /command="BookMarks" /qualifier="On"
;CmdName /appname="pdf" /command="BookMarks" /qualifier="Off"
;on by default
;=================================================================

;=================================================================
;Turn the Level/File optional content on and off
;CmdName /appname="pdf" /command="FileOptionalContent" /qualifier="On"
CmdName /appname="pdf" /command="FileOptionalContent" /qualifier="Off"
;off by default
;=================================================================

;=================================================================
;Turn Engineering links on and off
CmdName /appname="pdf" /command="EngineeringLinks" /qualifier="On"
;CmdName /appname="pdf" /command="EngineeringLinks" /qualifier="Off"
;on by default
;=================================================================

;=================================================================
;pick the version of pdf you want to support
CmdName /appname="pdf" /command="version" /qualifier="Acrobat 6 (PDF 1.5)/Viewable in Acrobat 5"
;CmdName /appname="pdf" /command="version" /qualifier="Acrobat 6 (PDF 1.5)"
;CmdName /appname="pdf" /command="version" /qualifier="Acrobat 5 (PDF 1.4)"
;=================================================================

;=================================================================
;uncomment the line and change the qualifier to your password
;if you wish to protect the output pdf file.
;NOTE the pdf file will not view with out the password
;But then is unprotected
;CmdName /appname="pdf" /command="userpassword" /qualifier="my_password"
;=================================================================

;=================================================================
;RGB Raster compression
;CmdName /appname="pdf" /command="RGBRasterCompression" /qualifier="jpeg"
CmdName /appname="pdf" /command="RGBRasterCompression" /qualifier="zipped"
;zipped by default
;=================================================================

;=================================================================
;Searchable Text
CmdName /appname="pdf" /command="SearchableText" /qualifier="on"
;CmdName /appname="pdf" /command="SearchableText" /qualifier="off"
;on by default
;=================================================================


; ENGLISH resolution and SIZE records
size=(11,8.5)/num=0/off=(0,0)/name="ANSI A"
size=(17,11)/num=0/off=(0,0)/name="ANSI B"
size=(22,17)/num=0/off=(0,0)/name="ANSI C"
size=(44,34)/num=0/off=(0,0)/name="ANSI E"
size=(34,22)/num=0/off=(0,0)/name="ANSI D"
resolution(IN)=(0.001666666666666666666667,0.001666666666666666666667) ;600DPI

; METRIC resolution and SIZE records
;size=(1189,841)/num=0/off=(0,0)/name="ISO A0"
;size=(841,594)/num=0/off=(0,0)/name="ISO A1"
;size=(594,420)/num=0/off=(0,0)/name="ISO A2"
;size=(420,297)/num=0/off=(0,0)/name="ISO A3"
;size=(297,210)/num=0/off=(0,0)/name="ISO A4"
;resolution(MM)=(0.04233333333333333333333,0.04233333333333333333333); 600DPI



;********************************************
;SHA SPECIFIC CUSTOMIZATION FOLLOWS:
;********************************************
;----------------------------------------------------------------+
;                                                                |
; Include files to allow for multiple plotter configurations and |
;         still mantain common settings.                         |
;                                                                |
;----------------------------------------------------------------+
%include "Sub_Common.inc"
%include "Sub_Full.inc"
%include "Sub_Color.inc"
